@@ -8,9 +8,12 @@ from sqlglot.helper import seq_get
 
 def _create_sql(self, e):
     kind = e.args.get("kind")
-    temporary = e.args.get("temporary")
+    properties = e.args.get("properties")
 
-    if kind.upper() == "TABLE" and temporary is True:
+    if kind.upper() == "TABLE" and any(
+        isinstance(prop, exp.TemporaryProperty)
+        for prop in (properties.expressions if properties else [])
+    ):
         return f"CREATE TEMPORARY VIEW {self.sql(e, 'this')} AS {self.sql(e, 'expression')}"
     return create_with_partitions_sql(self, e)
 
