@@ -286,7 +286,7 @@ class TypeAnnotator:
                     source = scope.sources.get(col.table)
                     if isinstance(source, exp.Table):
                         col.type = self.schema.get_column_type(source, col)
-                    elif source and col.table in selects:
+                    elif source and col.table in selects and col.name in selects[col.table]:
                         col.type = selects[col.table][col.name].type
                 # Then (possibly) annotate the remaining expressions in the scope
                 self._maybe_annotate(scope.expression)
