@@ -28,7 +28,7 @@ def qualify_tables(expression, db=None, catalog=None, schema=None):
     next_name = lambda: f"_q_{next(sequence)}"
 
     for scope in traverse_scope(expression):
-        for derived_table in scope.ctes + scope.derived_tables:
+        for derived_table in itertools.chain(scope.ctes, scope.derived_tables):
             if not derived_table.args.get("alias"):
                 alias_ = f"_q_{next(sequence)}"
                 derived_table.set("alias", exp.TableAlias(this=exp.to_identifier(alias_)))
